@@ -1,4 +1,4 @@
-from .handler import Handler, Metadata, handlers
+from .handler import Handler, handlers, Globber
 
 import jinja2
 
@@ -10,23 +10,33 @@ from pathlib import Path
 def process_dir(input_dir: Path, output_dir: Path, templates_path: Path = Path('templates')):
     template_env = jinja2.Environment(loader=jinja2.FileSystemLoader(templates_path))
 
-    handlers: list[Handler] = []
+    handlers: dict[Path, Handler] = {}
     process_dir_helper(input_dir, output_dir, Path('.'), template_env, handlers)
 
-    metadata = [Metadata(h.rel_input_path, h.rel_output_path, h.front_matter) for h in handlers]
-    for handler in handlers:
-        handler.handle(metadata)
+    for _, handler in handlers.items():
+        handler.handle()
+
+
+def process_file(input_file: Path, output_dir: Path, handler_class: Type[Handler],
+                 templates_path: Path = Path('templates')):
+    g = Globber()  # empty globber
+    input_root = input_file.parent
+    relative_input_path = input_file.relative_to(input_root)
+    template_env = jinja2.Environment(loader=jinja2.FileSystemLoader(templates_path))
+    handler = handler_class(input_root, relative_input_path, output_dir, template_env, g, g)
+    handler.handle()
 
 
 def process_dir_helper(input_root: Path, output_root: Path, rel_path: Path, template_env: jinja2.Environment,
-                       handlers: list[Handler]) -> None:
+                       handlers: dict[Path, Handler]) -> None:
     for input_path in (input_root / rel_path).iterdir():
         relative_input_path = input_path.relative_to(input_root)
-        handler_class = get_handler_class(relative_input_path)
+        handler_class = get_handler_class(input_root / relative_input_path)
 
         if handler_class is not None:
-            handler = handler_class(input_root, output_root, relative_input_path, template_env)
-            handlers.append(handler)
+            handler = handler_class(input_root, relative_input_path, output_root, template_env,
+                                    Globber(handlers), Globber(handlers, relative_input_path))
+            handlers[relative_input_path] = handler
             continue
 
         if input_path.is_dir():
